@@ -1,24 +1,19 @@
 use strict;
 use warnings;
-package signatures;
-BEGIN {
-  $signatures::AUTHORITY = 'cpan:FLORA';
-}
-# git description: v0.08-1-g1cfbe5b
-$signatures::VERSION = '0.09';
+package signatures; # git description: v0.11-10-g01eb9b6
 # ABSTRACT: Subroutine signatures with no source filter
 
+our $VERSION = '0.12';
+
 use XSLoader;
 use B::Hooks::Parser 0.12;
 use B::Hooks::OP::Check 0.17;
-use B::Hooks::OP::PPAddr;
-use B::Hooks::EndOfScope 0.08;
+use B::Hooks::OP::PPAddr 0.03;
+use B::Hooks::EndOfScope 0.08 ();
 
 XSLoader::load(
     __PACKAGE__,
-    exists $signatures::{VERSION}
-    ? ${ $signatures::{VERSION} }
-    : (),
+    $VERSION,
 );
 
 {
@@ -62,7 +57,7 @@ sub setup_for {
         };
     }
 
-    &on_scope_end($unregister);
+    &B::Hooks::EndOfScope::on_scope_end($unregister);
 
     return [$ret, $unregister];
 }
@@ -110,7 +105,7 @@ signatures - Subroutine signatures with no source filter
 
 =head1 VERSION
 
-version 0.09
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -230,18 +225,12 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
+=for stopwords Karen Etheridge Peter Martini Alexandr Ciornii Father Chrysostomos Alex Kapranoff Steffen Schwigon
+
 =over 4
 
 =item *
 
-Alex Kapranoff <alex@kapranoff.ru>
-
-=item *
-
-Alexandr Ciornii <alexchorny@gmail.com>
-
-=item *
-
 Karen Etheridge <ether@cpan.org>
 
 =item *
@@ -250,6 +239,18 @@ Peter Martini <PeterCMartini@GMail.com>
 
 =item *
 
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=item *
+
+Father Chrysostomos <sprout@cpan.org>
+
+=item *
+
+Alex Kapranoff <alex@kapranoff.ru>
+
+=item *
+
 Steffen Schwigon <ss5@renormalist.net>
 
 =back
